@@ -1,16 +1,11 @@
 use ckb_app_config::{ExitCode, ExportArgs};
 use ckb_async_runtime::Handle;
 use ckb_instrument::Export;
-use ckb_shared::SharedBuilder;
+use ckb_launcher::SharedBuilder;
 
 pub fn export(args: ExportArgs, async_handle: Handle) -> Result<(), ExitCode> {
-    let (shared, _) = SharedBuilder::new(&args.config.db, None, async_handle)
-        .consensus(args.consensus)
-        .build()
-        .map_err(|err| {
-            eprintln!("Export error: {:?}", err);
-            ExitCode::Failure
-        })?;
+    let builder = SharedBuilder::new(&args.config.db, None, async_handle)?;
+    let (shared, _) = builder.consensus(args.consensus).build()?;
     Export::new(shared, args.target).execute().map_err(|err| {
         eprintln!("Export error: {:?}", err);
         ExitCode::Failure
