@@ -2,16 +2,11 @@ use ckb_app_config::{ExitCode, ImportArgs};
 use ckb_async_runtime::Handle;
 use ckb_chain::chain::ChainService;
 use ckb_instrument::Import;
-use ckb_shared::SharedBuilder;
+use ckb_launcher::SharedBuilder;
 
 pub fn import(args: ImportArgs, async_handle: Handle) -> Result<(), ExitCode> {
-    let (shared, mut pack) = SharedBuilder::new(&args.config.db, None, async_handle)
-        .consensus(args.consensus)
-        .build()
-        .map_err(|err| {
-            eprintln!("Import error: {:?}", err);
-            ExitCode::Failure
-        })?;
+    let builder = SharedBuilder::new(&args.config.db, None, async_handle)?;
+    let (shared, mut pack) = builder.consensus(args.consensus).build()?;
 
     let chain_service = ChainService::new(shared, pack.take_proposal_table());
     let chain_controller = chain_service.start::<&str>(Some("ImportChainService"));
